@@ -14,6 +14,7 @@ class browser:
     display = ""
     driver = ""
     wait_timeout = 30
+    isClosed = ""
 
     def create_firefox(self, page_load_timeout, wait_timeout, add_log = True):
         self.create_browser(page_load_timeout, wait_timeout, False, None, add_log)
@@ -38,14 +39,17 @@ class browser:
 
         self.driver.set_page_load_timeout(page_load_timeout)
         self.wait_timeout = wait_timeout
+        self.isClosed = False
 
     def close(self, add_log = True):
-        if not sys.platform == 'win32':
-            self.add_and_print_log('Closing display', add_log)
-            self.display.stop()
+        if not self.isClosed:
+            if not sys.platform == 'win32':
+                self.add_and_print_log('Closing display', add_log)
+                self.display.stop()
 
-        self.add_and_print_log('Closing browser', add_log)
-        self.driver.close()
+            self.add_and_print_log('Closing browser', add_log)
+            self.driver.close()
+            self.isClosed = True
 
     def go_to(self, url, add_log = True):
         if (add_log):
